pub struct EmbassyRuntime;Available on crate feature
embassy only.Expand description
Concrete RuntimeLite implementation based on
embassy-executor.
Before any task is spawned through this runtime, the global spawner must be installed once with
init from within a running embassy executor. See the module documentation for the
caveats of this backend (block_on busy-polls, spawn_blocking and local spawning panic,
and the number of live spawned tasks is bounded by TASK_POOL_SIZE).