Instant

Struct Instant 

pub struct Instant(/* private fields */);
Available on crate feature embassy only.
A measurement of a monotonically nondecreasing clock, backed by embassy_time::Instant.

Sub-microsecond precision is truncated when converting to and from core::time::Duration.

Implementations

Source

impl Instant

pub fn now() -> Self

Returns an instant corresponding to “now”.

pub const fn into_embassy(self) -> Instant

Returns the underlying embassy_time::Instant.