AsyncSleepExt

Trait AsyncSleepExt 

pub trait AsyncSleepExt: AsyncSleep {
    // Required methods
    fn sleep(after: Duration) -> Self
       where Self: Sized;
    fn sleep_until(deadline: Self::Instant) -> Self
       where Self: Sized;
}
Available on crate feature time only.
Extension trait for AsyncSleep.

Required Methods

fn sleep(after: Duration) -> Self
where Self: Sized,

Creates a timer that emits an event once after the given duration of time.

fn sleep_until(deadline: Self::Instant) -> Self
where Self: Sized,

Creates a timer that emits an event once at the given time instant.

Implementors