pub struct Instant(/* private fields */);Available on crate feature
embassy only.Expand description
A measurement of a monotonically nondecreasing clock, backed by embassy_time::Instant.
Sub-microsecond precision is truncated when converting to and from core::time::Duration.
Implementations
Sourceimpl Instant
impl Instant
Sourcepub const fn into_embassy(self) -> Instant
pub const fn into_embassy(self) -> Instant
Returns the underlying embassy_time::Instant.