pub struct JoinError(/* private fields */);Available on crate feature
smol only.Expand description
Task failed to execute to completion.
This error will never be returned for smol runtime,
having it here is just for compatibility with other runtimes.